from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.create_signup_link_response import CreateSignupLinkResponse
from ...models.http_validation_error import HTTPValidationError
from ...types import UNSET, Response, Unset


def _get_kwargs(*, user_email: str, send_email: Union[Unset, bool] = True) -> dict[str, Any]:
    params: dict[str, Any] = {}

    params["user_email"] = user_email

    params["send_email"] = send_email

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {"method": "post", "url": "/signup_link", "params": params}

    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Union[CreateSignupLinkResponse, HTTPValidationError]]:
    if response.status_code == 200:
        response_200 = CreateSignupLinkResponse.from_dict(response.json())

        return response_200
    if response.status_code == 422:
        response_422 = HTTPValidationError.from_dict(response.json())

        return response_422
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[CreateSignupLinkResponse, HTTPValidationError]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *, client: AuthenticatedClient, user_email: str, send_email: Union[Unset, bool] = True
) -> Response[Union[CreateSignupLinkResponse, HTTPValidationError]]:
    """Generate Signup Link

     Generate a signup link for a new user.

    This endpoint is used by admins in the console Command Center.
    We create an unverified user entry and send a signup email to the new user.

    The user is then verified via one of the following endpoints:
    - POST /users
    - POST /users/social

    Args:
        user_email (str):
        send_email (Union[Unset, bool]):  Default: True.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[CreateSignupLinkResponse, HTTPValidationError]]
    """

    kwargs = _get_kwargs(user_email=user_email, send_email=send_email)

    response = client.get_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


def sync(
    *, client: AuthenticatedClient, user_email: str, send_email: Union[Unset, bool] = True
) -> Optional[Union[CreateSignupLinkResponse, HTTPValidationError]]:
    """Generate Signup Link

     Generate a signup link for a new user.

    This endpoint is used by admins in the console Command Center.
    We create an unverified user entry and send a signup email to the new user.

    The user is then verified via one of the following endpoints:
    - POST /users
    - POST /users/social

    Args:
        user_email (str):
        send_email (Union[Unset, bool]):  Default: True.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[CreateSignupLinkResponse, HTTPValidationError]
    """

    return sync_detailed(client=client, user_email=user_email, send_email=send_email).parsed


async def asyncio_detailed(
    *, client: AuthenticatedClient, user_email: str, send_email: Union[Unset, bool] = True
) -> Response[Union[CreateSignupLinkResponse, HTTPValidationError]]:
    """Generate Signup Link

     Generate a signup link for a new user.

    This endpoint is used by admins in the console Command Center.
    We create an unverified user entry and send a signup email to the new user.

    The user is then verified via one of the following endpoints:
    - POST /users
    - POST /users/social

    Args:
        user_email (str):
        send_email (Union[Unset, bool]):  Default: True.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[CreateSignupLinkResponse, HTTPValidationError]]
    """

    kwargs = _get_kwargs(user_email=user_email, send_email=send_email)

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *, client: AuthenticatedClient, user_email: str, send_email: Union[Unset, bool] = True
) -> Optional[Union[CreateSignupLinkResponse, HTTPValidationError]]:
    """Generate Signup Link

     Generate a signup link for a new user.

    This endpoint is used by admins in the console Command Center.
    We create an unverified user entry and send a signup email to the new user.

    The user is then verified via one of the following endpoints:
    - POST /users
    - POST /users/social

    Args:
        user_email (str):
        send_email (Union[Unset, bool]):  Default: True.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[CreateSignupLinkResponse, HTTPValidationError]
    """

    return (await asyncio_detailed(client=client, user_email=user_email, send_email=send_email)).parsed



import datetime
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

T = TypeVar("T", bound="EditReviewDB")


@_attrs_define
class EditReviewDB:
    """Reviewer of an edit.

    Attributes:
        created_at (datetime.datetime):
        created_by (str):
    """

    created_at: datetime.datetime
    created_by: str
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        created_at = self.created_at.isoformat()

        created_by = self.created_by

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({"created_at": created_at, "created_by": created_by})

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
        d = src_dict.copy()
        created_at = isoparse(d.pop("created_at"))

        created_by = d.pop("created_by")

        edit_review_db = cls(created_at=created_at, created_by=created_by)

        edit_review_db.additional_properties = d
        return edit_review_db

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from io import BytesIO
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import File

T = TypeVar("T", bound="BodyUploadPromptEvaluationDatasetProjectsProjectIdPromptDatasetsPost")


@_attrs_define
class BodyUploadPromptEvaluationDatasetProjectsProjectIdPromptDatasetsPost:
    """
    Attributes:
        file (File):
    """

    file: File
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        file = self.file.to_tuple()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({"file": file})

        return field_dict

    def to_multipart(self) -> dict[str, Any]:
        file = self.file.to_tuple()

        field_dict: dict[str, Any] = {}
        for prop_name, prop in self.additional_properties.items():
            field_dict[prop_name] = (None, str(prop).encode(), "text/plain")

        field_dict.update({"file": file})

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
        d = src_dict.copy()
        file = File(payload=BytesIO(d.pop("file")))

        body_upload_prompt_evaluation_dataset_projects_project_id_prompt_datasets_post = cls(file=file)

        body_upload_prompt_evaluation_dataset_projects_project_id_prompt_datasets_post.additional_properties = d
        return body_upload_prompt_evaluation_dataset_projects_project_id_prompt_datasets_post

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class Operator(str, Enum):
    BETWEEN = "between"
    CONTAINS = "contains"
    EQ = "eq"
    GT = "gt"
    GTE = "gte"
    HAS_ALL = "has_all"
    IN = "in"
    LIKE = "like"
    LT = "lt"
    LTE = "lte"
    NE = "ne"
    NOT_IN = "not_in"

    def __str__(self) -> str:
        return str(self.value)



import builtins
import json
import logging
from typing import Optional, Union

from galileo.base import BaseClientModel
from galileo.projects import Projects
from galileo.resources.api.prompts import (
    create_prompt_template_with_version_projects_project_id_templates_post,
    get_project_templates_projects_project_id_templates_get,
    get_template_from_project_projects_project_id_templates_template_id_get,
)
from galileo.resources.models import (
    BasePromptTemplateResponse,
    CreatePromptTemplateWithVersionRequestBody,
    HTTPValidationError,
    Message,
)

_logger = logging.getLogger(__name__)


class PromptTemplate(BaseClientModel):
    def list(self, project_name: str):
        project = Projects().get(name=project_name)
        if not project:
            raise ValueError(f"Project {project_name} does not exist")

        templates = get_project_templates_projects_project_id_templates_get.sync(
            # TODO: remove type ignore, when migrated to proper AuthenticatedClient
            project_id=project.id,
            client=self.client,  # type: ignore[arg-type]
        )
        return templates

    def get(
        self, *, project_name: str, template_id: str
    ) -> Optional[Union[BasePromptTemplateResponse, HTTPValidationError]]:
        project = Projects().get(name=project_name)
        if not project:
            raise ValueError(f"Project {project_name} does not exist")

        _logger.debug(f"Get template {template_id} from project {project.id}")
        template = get_template_from_project_projects_project_id_templates_template_id_get.sync(
            # TODO: remove type ignore, when migrated to proper AuthenticatedClient
            project_id=project.id,
            template_id=template_id,
            client=self.client,  # type: ignore[arg-type]
        )
        return template

    def create(
        self, name: str, project_name: str, template: Union[builtins.list[Message], str]
    ) -> Optional[Union[BasePromptTemplateResponse, HTTPValidationError]]:
        project = Projects().get(name=project_name)
        if not project:
            raise ValueError(f"Project {project_name} does not exist")

        body = CreatePromptTemplateWithVersionRequestBody(name=name, template=template)

        _logger.debug(f"{body}")
        response = create_prompt_template_with_version_projects_project_id_templates_post.sync_detailed(
            project_id=project.id,
            client=self.client,  # type: ignore[arg-type]
            body=body,
        )

        if not response.parsed:
            raise ValueError(json.loads(response.content)["detail"])

        return response.parsed


def create_prompt_template(
    name: str, project: str, messages: Union[list["Message"], str]
) -> Optional[Union[BasePromptTemplateResponse, HTTPValidationError]]:
    return PromptTemplate().create(name=name, project_name=project, template=messages)


def get_prompt_template(project: str, name: str) -> Optional[Union[BasePromptTemplateResponse, HTTPValidationError]]:
    prompt_templates = PromptTemplate().list(project_name=project)
    for prompt_template in prompt_templates:
        if prompt_template.name == name:
            _logger.info(f"Get template {prompt_template}")
            return prompt_template
    raise ValueError(f"Prompt {name} does not exist")



from typing import TYPE_CHECKING, Any, Literal, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.anthropic_integration_extra_type_0 import AnthropicIntegrationExtraType0


T = TypeVar("T", bound="AnthropicIntegration")


@_attrs_define
class AnthropicIntegration:
    """
    Attributes:
        extra (Union['AnthropicIntegrationExtraType0', None, Unset]):
        name (Union[Literal['anthropic'], Unset]):  Default: 'anthropic'.
    """

    extra: Union["AnthropicIntegrationExtraType0", None, Unset] = UNSET
    name: Union[Literal["anthropic"], Unset] = "anthropic"
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        from ..models.anthropic_integration_extra_type_0 import AnthropicIntegrationExtraType0

        extra: Union[None, Unset, dict[str, Any]]
        if isinstance(self.extra, Unset):
            extra = UNSET
        elif isinstance(self.extra, AnthropicIntegrationExtraType0):
            extra = self.extra.to_dict()
        else:
            extra = self.extra

        name = self.name

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if extra is not UNSET:
            field_dict["extra"] = extra
        if name is not UNSET:
            field_dict["name"] = name

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
        from ..models.anthropic_integration_extra_type_0 import AnthropicIntegrationExtraType0

        d = src_dict.copy()

        def _parse_extra(data: object) -> Union["AnthropicIntegrationExtraType0", None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                extra_type_0 = AnthropicIntegrationExtraType0.from_dict(data)

                return extra_type_0
            except:  # noqa: E722
                pass
            return cast(Union["AnthropicIntegrationExtraType0", None, Unset], data)

        extra = _parse_extra(d.pop("extra", UNSET))

        name = cast(Union[Literal["anthropic"], Unset], d.pop("name", UNSET))
        if name != "anthropic" and not isinstance(name, Unset):
            raise ValueError(f"name must match const 'anthropic', got '{name}'")

        anthropic_integration = cls(extra=extra, name=name)

        anthropic_integration.additional_properties = d
        return anthropic_integration

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class ColumnCategory(str, Enum):
    METRIC = "metric"
    STANDARD = "standard"
    USER_METADATA = "user_metadata"

    def __str__(self) -> str:
        return str(self.value)



from typing import TYPE_CHECKING, Any, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.split import Split
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.filter_params import FilterParams
    from ..models.top_insights_response_top_correlation_pairs import TopInsightsResponseTopCorrelationPairs
    from ..models.top_insights_response_top_erroneous_words import TopInsightsResponseTopErroneousWords
    from ..models.top_insights_response_top_misclassified_pairs_item import TopInsightsResponseTopMisclassifiedPairsItem


T = TypeVar("T", bound="TopInsightsResponse")


@_attrs_define
class TopInsightsResponse:
    """
    Attributes:
        top_misclassified_pairs_percentage (float):
        compare_to (Union[None, Split, Unset]):
        filter_params (Union[Unset, FilterParams]):
        map_threshold (Union[Unset, float]):  Default: 0.5.
        meta_cols (Union[None, Unset, list[str]]):
        task (Union[None, Unset, str]):
        top_correlation_pairs (Union[Unset, TopInsightsResponseTopCorrelationPairs]):
        top_erroneous_words (Union[Unset, TopInsightsResponseTopErroneousWords]):
        top_misclassified_pairs (Union[Unset, list['TopInsightsResponseTopMisclassifiedPairsItem']]):
    """

    top_misclassified_pairs_percentage: float
    compare_to: Union[None, Split, Unset] = UNSET
    filter_params: Union[Unset, "FilterParams"] = UNSET
    map_threshold: Union[Unset, float] = 0.5
    meta_cols: Union[None, Unset, list[str]] = UNSET
    task: Union[None, Unset, str] = UNSET
    top_correlation_pairs: Union[Unset, "TopInsightsResponseTopCorrelationPairs"] = UNSET
    top_erroneous_words: Union[Unset, "TopInsightsResponseTopErroneousWords"] = UNSET
    top_misclassified_pairs: Union[Unset, list["TopInsightsResponseTopMisclassifiedPairsItem"]] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        top_misclassified_pairs_percentage = self.top_misclassified_pairs_percentage

        compare_to: Union[None, Unset, str]
        if isinstance(self.compare_to, Unset):
            compare_to = UNSET
        elif isinstance(self.compare_to, Split):
            compare_to = self.compare_to.value
        else:
            compare_to = self.compare_to

        filter_params: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.filter_params, Unset):
            filter_params = self.filter_params.to_dict()

        map_threshold = self.map_threshold

        meta_cols: Union[None, Unset, list[str]]
        if isinstance(self.meta_cols, Unset):
            meta_cols = UNSET
        elif isinstance(self.meta_cols, list):
            meta_cols = self.meta_cols

        else:
            meta_cols = self.meta_cols

        task: Union[None, Unset, str]
        if isinstance(self.task, Unset):
            task = UNSET
        else:
            task = self.task

        top_correlation_pairs: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.top_correlation_pairs, Unset):
            top_correlation_pairs = self.top_correlation_pairs.to_dict()

        top_erroneous_words: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.top_erroneous_words, Unset):
            top_erroneous_words = self.top_erroneous_words.to_dict()

        top_misclassified_pairs: Union[Unset, list[dict[str, Any]]] = UNSET
        if not isinstance(self.top_misclassified_pairs, Unset):
            top_misclassified_pairs = []
            for top_misclassified_pairs_item_data in self.top_misclassified_pairs:
                top_misclassified_pairs_item = top_misclassified_pairs_item_data.to_dict()
                top_misclassified_pairs.append(top_misclassified_pairs_item)

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({"top_misclassified_pairs_percentage": top_misclassified_pairs_percentage})
        if compare_to is not UNSET:
            field_dict["compare_to"] = compare_to
        if filter_params is not UNSET:
            field_dict["filter_params"] = filter_params
        if map_threshold is not UNSET:
            field_dict["map_threshold"] = map_threshold
        if meta_cols is not UNSET:
            field_dict["meta_cols"] = meta_cols
        if task is not UNSET:
            field_dict["task"] = task
        if top_correlation_pairs is not UNSET:
            field_dict["top_correlation_pairs"] = top_correlation_pairs
        if top_erroneous_words is not UNSET:
            field_dict["top_erroneous_words"] = top_erroneous_words
        if top_misclassified_pairs is not UNSET:
            field_dict["top_misclassified_pairs"] = top_misclassified_pairs

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
        from ..models.filter_params import FilterParams
        from ..models.top_insights_response_top_correlation_pairs import TopInsightsResponseTopCorrelationPairs
        from ..models.top_insights_response_top_erroneous_words import TopInsightsResponseTopErroneousWords
        from ..models.top_insights_response_top_misclassified_pairs_item import (
            TopInsightsResponseTopMisclassifiedPairsItem,
        )

        d = src_dict.copy()
        top_misclassified_pairs_percentage = d.pop("top_misclassified_pairs_percentage")

        def _parse_compare_to(data: object) -> Union[None, Split, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                compare_to_type_0 = Split(data)

                return compare_to_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Split, Unset], data)

        compare_to = _parse_compare_to(d.pop("compare_to", UNSET))

        _filter_params = d.pop("filter_params", UNSET)
        filter_params: Union[Unset, FilterParams]
        if isinstance(_filter_params, Unset):
            filter_params = UNSET
        else:
            filter_params = FilterParams.from_dict(_filter_params)

        map_threshold = d.pop("map_threshold", UNSET)

        def _parse_meta_cols(data: object) -> Union[None, Unset, list[str]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                meta_cols_type_0 = cast(list[str], data)

                return meta_cols_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, list[str]], data)

        meta_cols = _parse_meta_cols(d.pop("meta_cols", UNSET))

        def _parse_task(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        task = _parse_task(d.pop("task", UNSET))

        _top_correlation_pairs = d.pop("top_correlation_pairs", UNSET)
        top_correlation_pairs: Union[Unset, TopInsightsResponseTopCorrelationPairs]
        if isinstance(_top_correlation_pairs, Unset):
            top_correlation_pairs = UNSET
        else:
            top_correlation_pairs = TopInsightsResponseTopCorrelationPairs.from_dict(_top_correlation_pairs)

        _top_erroneous_words = d.pop("top_erroneous_words", UNSET)
        top_erroneous_words: Union[Unset, TopInsightsResponseTopErroneousWords]
        if isinstance(_top_erroneous_words, Unset):
            top_erroneous_words = UNSET
        else:
            top_erroneous_words = TopInsightsResponseTopErroneousWords.from_dict(_top_erroneous_words)

        top_misclassified_pairs = []
        _top_misclassified_pairs = d.pop("top_misclassified_pairs", UNSET)
        for top_misclassified_pairs_item_data in _top_misclassified_pairs or []:
            top_misclassified_pairs_item = TopInsightsResponseTopMisclassifiedPairsItem.from_dict(
                top_misclassified_pairs_item_data
            )

            top_misclassified_pairs.append(top_misclassified_pairs_item)

        top_insights_response = cls(
            top_misclassified_pairs_percentage=top_misclassified_pairs_percentage,
            compare_to=compare_to,
            filter_params=filter_params,
            map_threshold=map_threshold,
            meta_cols=meta_cols,
            task=task,
            top_correlation_pairs=top_correlation_pairs,
            top_erroneous_words=top_erroneous_words,
            top_misclassified_pairs=top_misclassified_pairs,
        )

        top_insights_response.additional_properties = d
        return top_insights_response

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="ExtraAlertFilters")


@_attrs_define
class ExtraAlertFilters:
    """Extra filters for alerts.

    For simplicity of use, all types should be str to make filtering in the DB easier

        Attributes:
            map_threshold (Union[None, Unset, str]):
    """

    map_threshold: Union[None, Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        map_threshold: Union[None, Unset, str]
        if isinstance(self.map_threshold, Unset):
            map_threshold = UNSET
        else:
            map_threshold = self.map_threshold

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if map_threshold is not UNSET:
            field_dict["map_threshold"] = map_threshold

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
        d = src_dict.copy()

        def _parse_map_threshold(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        map_threshold = _parse_map_threshold(d.pop("map_threshold", UNSET))

        extra_alert_filters = cls(map_threshold=map_threshold)

        extra_alert_filters.additional_properties = d
        return extra_alert_filters

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.split import Split
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.circle import Circle
    from ..models.embedding_data import EmbeddingData
    from ..models.filter_params import FilterParams


T = TypeVar("T", bound="EmbeddingPointResponse")


@_attrs_define
class EmbeddingPointResponse:
    """
    Attributes:
        embedding_data (list['EmbeddingData']):
        circle (Union['Circle', None, Unset]):
        compare_to (Union[None, Split, Unset]):
        filter_params (Union[Unset, FilterParams]):
        ids (Union[Unset, list[int]]):
        map_threshold (Union[Unset, float]):  Default: 0.5.
        meta_cols (Union[None, Unset, list[str]]):
        num_samples (Union[Unset, int]):  Default: 5.
        task (Union[None, Unset, str]):
    """

    embedding_data: list["EmbeddingData"]
    circle: Union["Circle", None, Unset] = UNSET
    compare_to: Union[None, Split, Unset] = UNSET
    filter_params: Union[Unset, "FilterParams"] = UNSET
    ids: Union[Unset, list[int]] = UNSET
    map_threshold: Union[Unset, float] = 0.5
    meta_cols: Union[None, Unset, list[str]] = UNSET
    num_samples: Union[Unset, int] = 5
    task: Union[None, Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        from ..models.circle import Circle

        embedding_data = []
        for embedding_data_item_data in self.embedding_data:
            embedding_data_item = embedding_data_item_data.to_dict()
            embedding_data.append(embedding_data_item)

        circle: Union[None, Unset, dict[str, Any]]
        if isinstance(self.circle, Unset):
            circle = UNSET
        elif isinstance(self.circle, Circle):
            circle = self.circle.to_dict()
        else:
            circle = self.circle

        compare_to: Union[None, Unset, str]
        if isinstance(self.compare_to, Unset):
            compare_to = UNSET
        elif isinstance(self.compare_to, Split):
            compare_to = self.compare_to.value
        else:
            compare_to = self.compare_to

        filter_params: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.filter_params, Unset):
            filter_params = self.filter_params.to_dict()

        ids: Union[Unset, list[int]] = UNSET
        if not isinstance(self.ids, Unset):
            ids = self.ids

        map_threshold = self.map_threshold

        meta_cols: Union[None, Unset, list[str]]
        if isinstance(self.meta_cols, Unset):
            meta_cols = UNSET
        elif isinstance(self.meta_cols, list):
            meta_cols = self.meta_cols

        else:
            meta_cols = self.meta_cols

        num_samples = self.num_samples

        task: Union[None, Unset, str]
        if isinstance(self.task, Unset):
            task = UNSET
        else:
            task = self.task

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({"embedding_data": embedding_data})
        if circle is not UNSET:
            field_dict["circle"] = circle
        if compare_to is not UNSET:
            field_dict["compare_to"] = compare_to
        if filter_params is not UNSET:
            field_dict["filter_params"] = filter_params
        if ids is not UNSET:
            field_dict["ids"] = ids
        if map_threshold is not UNSET:
            field_dict["map_threshold"] = map_threshold
        if meta_cols is not UNSET:
            field_dict["meta_cols"] = meta_cols
        if num_samples is not UNSET:
            field_dict["num_samples"] = num_samples
        if task is not UNSET:
            field_dict["task"] = task

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
        from ..models.circle import Circle
        from ..models.embedding_data import EmbeddingData
        from ..models.filter_params import FilterParams

        d = src_dict.copy()
        embedding_data = []
        _embedding_data = d.pop("embedding_data")
        for embedding_data_item_data in _embedding_data:
            embedding_data_item = EmbeddingData.from_dict(embedding_data_item_data)

            embedding_data.append(embedding_data_item)

        def _parse_circle(data: object) -> Union["Circle", None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                circle_type_0 = Circle.from_dict(data)

                return circle_type_0
            except:  # noqa: E722
                pass
            return cast(Union["Circle", None, Unset], data)

        circle = _parse_circle(d.pop("circle", UNSET))

        def _parse_compare_to(data: object) -> Union[None, Split, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                compare_to_type_0 = Split(data)

                return compare_to_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Split, Unset], data)

        compare_to = _parse_compare_to(d.pop("compare_to", UNSET))

        _filter_params = d.pop("filter_params", UNSET)
        filter_params: Union[Unset, FilterParams]
        if isinstance(_filter_params, Unset):
            filter_params = UNSET
        else:
            filter_params = FilterParams.from_dict(_filter_params)

        ids = cast(list[int], d.pop("ids", UNSET))

        map_threshold = d.pop("map_threshold", UNSET)

        def _parse_meta_cols(data: object) -> Union[None, Unset, list[str]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                meta_cols_type_0 = cast(list[str], data)

                return meta_cols_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, list[str]], data)

        meta_cols = _parse_meta_cols(d.pop("meta_cols", UNSET))

        num_samples = d.pop("num_samples", UNSET)

        def _parse_task(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        task = _parse_task(d.pop("task", UNSET))

        embedding_point_response = cls(
            embedding_data=embedding_data,
            circle=circle,
            compare_to=compare_to,
            filter_params=filter_params,
            ids=ids,
            map_threshold=map_threshold,
            meta_cols=meta_cols,
            num_samples=num_samples,
            task=task,
        )

        embedding_point_response.additional_properties = d
        return embedding_point_response

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
